@@ -43,7 +43,8 @@ def setup(settings_path=None, **settings_patches):
             with lcd(uwsgi_src_folder):
                 # Create build configuration
                 local('mkdir -p /usr/local/lib/uwsgi')
-                local('echo "inherit = default" >> buildconf/beanstalk.ini')
+                local('echo "[uwsgi]" >> buildconf/beanstalk.ini')
+                local('echo "inherit = base" >> buildconf/beanstalk.ini')
                 local('echo "plugin_dir = /usr/local/lib/uwsgi" >> buildconf/beanstalk.ini')
                 # Build and install
                 local('python uwsgiconfig.py --build beanstalk')
